reset method
void
reset()
Called after a flush so the policy can restart its counters/timers.
Implementation
void reset() {
shouldFlush = false;
}
Called after a flush so the policy can restart its counters/timers.
void reset() {
shouldFlush = false;
}