LiquidCapability enum

The kinds of messages a LiquidSink is able to handle.

A sink advertises its capabilities so the client can skip sinks that cannot process a given message type (e.g. a lightweight sink that only supports track will never be asked to group).

Inheritance
Available extensions

Values

track → const LiquidCapability

Handles track (custom named events).

screen → const LiquidCapability

Handles screen/page-view events.

identify → const LiquidCapability

Handles identify (associating a user id + traits).

group → const LiquidCapability

Handles group (associating a user with an account/organization).

alias → const LiquidCapability

Handles alias (merging an anonymous id into a known id).

reset → const LiquidCapability

Handles reset (clearing the current user/session).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LiquidCapability>
A constant List of the values in this enum, in order of their declaration.