onFlushRequested property
void Function()?
onFlushRequested
getter/setter pair
Set by the delivery engine so a policy can wake it the moment a flush is due. Not intended to be assigned by policy implementations.
Implementation
void Function()? onFlushRequested;